@@ -1,5 +1,5 @@
 #include <sys/types.h>
-#include <musepack/musepack.h>
+#include <mpcdec/mpcdec.h>
 
 int main (int argc, char **argv) {
     return 0;
